==> aws-android-sdk-cognitoidentityprovider-2.6.22-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/transform/CreateUserPoolDomainResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model.transform;

import com.amazonaws.services.cognitoidentityprovider.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response CreateUserPoolDomainResult
 */
public class CreateUserPoolDomainResultJsonUnmarshaller implements
        Unmarshaller<CreateUserPoolDomainResult, JsonUnmarshallerContext> {

    public CreateUserPoolDomainResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        CreateUserPoolDomainResult createUserPoolDomainResult = new CreateUserPoolDomainResult();

        return createUserPoolDomainResult;
    }

    private static CreateUserPoolDomainResultJsonUnmarshaller instance;

    public static CreateUserPoolDomainResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CreateUserPoolDomainResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-cognitoidentityprovider-2.8.2-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/transform/CreateUserPoolDomainResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model.transform;

import com.amazonaws.services.cognitoidentityprovider.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response CreateUserPoolDomainResult
 */
public class CreateUserPoolDomainResultJsonUnmarshaller implements
        Unmarshaller<CreateUserPoolDomainResult, JsonUnmarshallerContext> {

    public CreateUserPoolDomainResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        CreateUserPoolDomainResult createUserPoolDomainResult = new CreateUserPoolDomainResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("CloudFrontDomain")) {
                createUserPoolDomainResult.setCloudFrontDomain(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return createUserPoolDomainResult;
    }

    private static CreateUserPoolDomainResultJsonUnmarshaller instance;

    public static CreateUserPoolDomainResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CreateUserPoolDomainResultJsonUnmarshaller();
        return instance;
    }
}
